/*
 *  /MathJax-v2/localization/pt-br/HTML-CSS.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("pt-br","HTML-CSS",{version:"2.7.8",isLoaded:true,strings:{LoadWebFont:"Carregando fonte baseada em web %1",CantLoadWebFont:"N\u00E3o foi poss\u00EDvel carregar a fonte baseada em web %1",FirefoxCantLoadWebFont:"O Firefox N\u00E3o pode carregar fontes baseadas em web a partir de um host remoto",CantFindFontUsing:"N\u00E3o \u00E9 poss\u00EDvel encontrar uma fonte v\u00E1lida usando %1",WebFontsNotAvailable:"Fontes baseadas em web n\u00E3o est\u00E3o dispon\u00EDveis -- usando fontes feitas com imagens em vez disso"}});MathJax.Ajax.loadComplete("[MathJax]/localization/pt-br/HTML-CSS.js");
