// minimal imports from bootstrap - only variables and mixins
@import "../components/bootstrap/less/variables.less";
@import "../components/bootstrap/less/mixins.less";

// minimal imports from font-awesome
@import "../components/font-awesome/less/variables.less";

// base
@import "../base/less/style.less";

// notebook
@import "../notebook/less/style_noapp.less";
