/*
 *  /MathJax-v2/localization/ia/FontWarnings.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("ia","FontWarnings",{version:"2.7.8",isLoaded:true,strings:{webFont:"MathJax utilisa typos de litteras discargate del web pro presentar le formulas mathematic in iste pagina. Istes require tempore pro esser discargate; le pagina apparerea plus rapidemente si vos installa le typos de characteres mathematic directemente in le dossier de typos de litteras de vostre computator.",imageFonts:"MathJax presenta le characteres mathematic per medio de imagines e non usa typos de litteras web o local. Isto rende le presentation plus lente e vostre impressor pote imprimer le formulas a un resolution basse.",noFonts:"MathJax non ha potite localisar un typo de litteras pro presentar su formulas mathematic, e le characteres in imagines non es disponibile, dunque illo debe usar le characteres Unicode generic in le sperantia que vostre navigator sape monstrar los correctemente. Alcun characteres pote apparer de modo erronee o esser absente.",webFonts:"Le major parte del navigatores moderne permitte le discargamento de typos de litteras per le web. Si vos actualisa le version de vostre navigator (o cambia de navigator) le qualitate graphic del formulas mathematic in iste pagina poterea meliorar se.",fonts:"MathJax pote usar le [typos de litteras STIX](%1) o le [typos de litteras TeX de MathJax](%2). Discarga e installa un de istes pro meliorar vostre expreientia de MathJax.",STIXPage:"Iste pagina ha essite concipite pro usar le [typos de litteras STIX](%1). Discarga e installa istes pro meliorar vostre experientia con MathJax.",TeXPage:"Iste pagina ha essite concipite pro usar le [typos de litteras TeX de MathJax](%1). Discarga e installa istes pro meliorar vostre experientia con MathJax."}});MathJax.Ajax.loadComplete("[MathJax]/localization/ia/FontWarnings.js");
