/*
 *  /MathJax-v2/localization/zh-hans/FontWarnings.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("zh-hans","FontWarnings",{version:"2.7.8",isLoaded:true,strings:{webFont:"MathJax\u4F7F\u7528\u57FA\u4E8EWeb\u7684\u5B57\u4F53\u6765\u663E\u793A\u6B64\u9875\u4E0A\u663E\u793A\u6570\u5B66\u76F8\u5173\u5185\u5BB9\u3002\u8FD9\u5C06\u82B1\u8D39\u8F83\u957F\u65F6\u95F4\u4E0B\u8F7D\uFF0C\u6240\u4EE5\u6211\u4EEC\u5F3A\u70C8\u5EFA\u8BAE\u60A8\u76F4\u63A5\u5728\u60A8\u7684\u64CD\u4F5C\u7CFB\u7EDF\u7684\u5B57\u4F53\u6587\u4EF6\u5939\u4E2D\u5B89\u88C5\u6570\u5B66\u7B26\u53F7\u5B57\u4F53\u4EE5\u4FBF\u7ACB\u523B\u663E\u793A\u3002",imageFonts:"MathJax\u4F7F\u7528\u56FE\u50CF\u5B57\u4F53\u800C\u4E0D\u662F\u672C\u5730\u6216\u57FA\u4E8EWeb\u7684\u5B57\u4F53\u3002\u8FD9\u5C06\u6BD4\u5E73\u5E38\u663E\u793A\u66F4\u6162\uFF0C\u4E14\u76F8\u5173\u6570\u5B66\u7B26\u53F7\u53EF\u80FD\u65E0\u6CD5\u5168\u606F\u7684\u88AB\u6253\u5370\u673A\u6253\u5370\u3002",noFonts:"MathJax\u65E0\u6CD5\u5B9A\u4F4D\u60A8\u4F7F\u7528\u4E2D\u7684\u5B57\u4F53\u4EE5\u663E\u793A\u6570\u5B66\u7B26\u53F7\uFF0C\u56FE\u50CF\u5B57\u4F53\u4EA6\u65E0\u6CD5\u4F7F\u7528\uFF0C\u6240\u4EE5\u6211\u4EEC\u4E0D\u5F97\u4E0D\u8C03\u7528Unicode\u5B57\u7B26\u4EE5\u663E\u793A\u4E4B\u3002\u67D0\u4E9B\u5B57\u7B26\u5C06\u65E0\u6CD5\u6B63\u786E\u663E\u793A\uFF0C\u4E43\u81F3\u5F7B\u5E95\u65E0\u6CD5\u663E\u793A\u3002",webFonts:"\u73B0\u65F6\u5927\u591A\u6570\u6D4F\u89C8\u5668\u5141\u8BB8\u901A\u8FC7\u4E92\u8054\u7F51\u4E0B\u8F7D\u5B57\u4F53\u3002\u66F4\u65B0\u60A8\u7684\u6D4F\u89C8\u5668\u81F3\u6700\u65B0\u7248\u672C\uFF08\u6216\u8005\u5E72\u8106\u66F4\u6362\u6D4F\u89C8\u5668\uFF09\u4EE5\u4FBF\u5728\u6B64\u9875\u9762\u63D0\u9AD8\u6570\u5B66\u7B26\u53F7\u7684\u663E\u793A\u8D28\u91CF\u3002",fonts:"MathJax\u53EF\u4F7F\u7528[STIX fonts](%1)\u6216\u8005[MathJax TeX fonts](%2)\u3002\u4E0B\u8F7D\u5E76\u5B89\u88C5\u8FD9\u4E9B\u5B57\u4F53\u4EE5\u6539\u5584\u60A8\u7684MathJax\u4F53\u9A8C\u3002",STIXPage:"\u6B64\u9875\u9762\u88AB\u8BBE\u8BA1\u4E3A\u4F7F\u7528[STIX fonts](%1)\u3002\u4E0B\u8F7D\u5E76\u5B89\u88C5\u5B83\u4EE5\u589E\u52A0\u60A8\u7684MathJax\u4F53\u9A8C\u3002",TeXPage:"\u6B64\u9875\u9762\u88AB\u8BBE\u8BA1\u4E3A\u4F7F\u7528[MathJax TeX fonts](%1)\u3002\u4E0B\u8F7D\u5E76\u5B89\u88C5\u5B83\u4EE5\u589E\u52A0\u60A8\u7684MathJax\u4F53\u9A8C\u3002"}});MathJax.Ajax.loadComplete("[MathJax]/localization/zh-hans/FontWarnings.js");
